
From: Martin Waitz <tali@admingilde.org>

Kernel-docify comments

Signed-off-by: Martin Waitz <tali@admingilde.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/kfifo.h |   12 ++++++------
 25-akpm/kernel/kfifo.c        |   10 +++++-----
 2 files changed, 11 insertions(+), 11 deletions(-)

diff -puN include/linux/kfifo.h~docbook-kernel-docify-comments include/linux/kfifo.h
--- 25/include/linux/kfifo.h~docbook-kernel-docify-comments	Thu Mar  3 16:55:32 2005
+++ 25-akpm/include/linux/kfifo.h	Thu Mar  3 16:55:32 2005
@@ -44,7 +44,7 @@ extern unsigned int __kfifo_put(struct k
 extern unsigned int __kfifo_get(struct kfifo *fifo,
 				unsigned char *buffer, unsigned int len);
 
-/*
+/**
  * __kfifo_reset - removes the entire FIFO contents, no locking version
  * @fifo: the fifo to be emptied.
  */
@@ -53,7 +53,7 @@ static inline void __kfifo_reset(struct 
 	fifo->in = fifo->out = 0;
 }
 
-/*
+/**
  * kfifo_reset - removes the entire FIFO contents
  * @fifo: the fifo to be emptied.
  */
@@ -68,7 +68,7 @@ static inline void kfifo_reset(struct kf
 	spin_unlock_irqrestore(fifo->lock, flags);
 }
 
-/*
+/**
  * kfifo_put - puts some data into the FIFO
  * @fifo: the fifo to be used.
  * @buffer: the data to be added.
@@ -93,7 +93,7 @@ static inline unsigned int kfifo_put(str
 	return ret;
 }
 
-/*
+/**
  * kfifo_get - gets some data from the FIFO
  * @fifo: the fifo to be used.
  * @buffer: where the data must be copied.
@@ -124,7 +124,7 @@ static inline unsigned int kfifo_get(str
 	return ret;
 }
 
-/*
+/**
  * __kfifo_len - returns the number of bytes available in the FIFO, no locking version
  * @fifo: the fifo to be used.
  */
@@ -133,7 +133,7 @@ static inline unsigned int __kfifo_len(s
 	return fifo->in - fifo->out;
 }
 
-/*
+/**
  * kfifo_len - returns the number of bytes available in the FIFO
  * @fifo: the fifo to be used.
  */
diff -puN kernel/kfifo.c~docbook-kernel-docify-comments kernel/kfifo.c
--- 25/kernel/kfifo.c~docbook-kernel-docify-comments	Thu Mar  3 16:55:32 2005
+++ 25-akpm/kernel/kfifo.c	Thu Mar  3 16:55:32 2005
@@ -25,7 +25,7 @@
 #include <linux/err.h>
 #include <linux/kfifo.h>
 
-/*
+/**
  * kfifo_init - allocates a new FIFO using a preallocated buffer
  * @buffer: the preallocated buffer to be used.
  * @size: the size of the internal buffer, this have to be a power of 2.
@@ -56,7 +56,7 @@ struct kfifo *kfifo_init(unsigned char *
 }
 EXPORT_SYMBOL(kfifo_init);
 
-/*
+/**
  * kfifo_alloc - allocates a new FIFO and its internal buffer
  * @size: the size of the internal buffer to be allocated.
  * @gfp_mask: get_free_pages mask, passed to kmalloc()
@@ -91,7 +91,7 @@ struct kfifo *kfifo_alloc(unsigned int s
 }
 EXPORT_SYMBOL(kfifo_alloc);
 
-/*
+/**
  * kfifo_free - frees the FIFO
  * @fifo: the fifo to be freed.
  */
@@ -102,7 +102,7 @@ void kfifo_free(struct kfifo *fifo)
 }
 EXPORT_SYMBOL(kfifo_free);
 
-/*
+/**
  * __kfifo_put - puts some data into the FIFO, no locking version
  * @fifo: the fifo to be used.
  * @buffer: the data to be added.
@@ -135,7 +135,7 @@ unsigned int __kfifo_put(struct kfifo *f
 }
 EXPORT_SYMBOL(__kfifo_put);
 
-/*
+/**
  * __kfifo_get - gets some data from the FIFO, no locking version
  * @fifo: the fifo to be used.
  * @buffer: where the data must be copied.
_
